{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "id": "#index_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: BAM to FASTQ",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "SamToFastq"
            ],
            "arguments": [
                {
                    "valueFrom": "F=$(runtime.outdir)/read1.fastq"
                },
                {
                    "valueFrom": "F2=$(runtime.outdir)/read2.fastq"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#bam_to_fastq.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "read1.fastq"
                    },
                    "id": "#bam_to_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "read2.fastq"
                    },
                    "id": "#bam_to_fastq.cwl/fastq2"
                }
            ],
            "id": "#bam_to_fastq.cwl"
        },
        {
            "class": "Workflow",
            "label": "bam to trimmed fastqs and HISAT alignments",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/adapters"
                },
                {
                    "type": "File",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/firststrand"
                },
                {
                    "type": "int",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/min_readlength"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/read_group_fields"
                },
                {
                    "type": "string",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/read_group_id"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".1.ht2",
                        ".2.ht2",
                        ".3.ht2",
                        ".4.ht2",
                        ".5.ht2",
                        ".6.ht2",
                        ".7.ht2",
                        ".8.ht2"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/reference_index"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/secondstrand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/aligned_bam",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/aligned_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/fastqs",
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/fastqs"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_fastq.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam_to_fastq/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam_to_fastq/fastq1",
                        "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam_to_fastq/fastq2"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam_to_fastq"
                },
                {
                    "run": "#hisat2_align.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/fastqs",
                            "valueFrom": "$(self[0])",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/fastq1"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/fastqs",
                            "valueFrom": "$(self[1])",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/fastq2"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/firststrand",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/firststrand"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/read_group_fields",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/read_group_fields"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/read_group_id",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/read_group_id"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/reference_index",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/reference_index"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/secondstrand",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/secondstrand"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align/aligned_bam"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/hisat2_align"
                },
                {
                    "run": "#trim_fastq.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/adapter_min_overlap",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/adapter_min_overlap"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/adapter_trim_end",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/adapter_trim_end"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/adapters",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/adapters"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/max_uncalled",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/max_uncalled"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/min_readlength",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/min_readlength"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam_to_fastq/fastq1",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/reads1"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/bam_to_fastq/fastq2",
                            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/reads2"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq/fastqs"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl/trim_fastq"
                }
            ],
            "id": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: RNA Seq Metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/picard/picard.jar",
                "CollectRnaSeqMetrics"
            ],
            "arguments": [
                {
                    "valueFrom": "O=$(runtime.outdir)/rna_metrics.txt"
                },
                {
                    "valueFrom": "CHART=$(runtime.outdir)/rna_metrics.pdf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "REF_FLAT=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/refFlat"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "RIBOSOMAL_INTERVALS=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/ribosomal_intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "STRAND=",
                        "separate": false
                    },
                    "id": "#generate_qc_metrics.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rna_metrics.pdf"
                    },
                    "id": "#generate_qc_metrics.cwl/chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rna_metrics.txt"
                    },
                    "id": "#generate_qc_metrics.cwl/metrics"
                }
            ],
            "id": "#generate_qc_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HISAT2: align",
            "baseCommand": [
                "/usr/bin/hisat2"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 16
                }
            ],
            "arguments": [
                "-p",
                "$(runtime.cores)",
                "--dta",
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/usr/bin/sambamba",
                "view",
                "-S",
                "-f",
                "bam",
                "-l",
                "0",
                "/dev/stdin",
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/usr/bin/sambamba",
                "sort",
                "-t",
                "$(runtime.cores)",
                "-m",
                "8G",
                "-o",
                "$(runtime.outdir)/aligned.bam",
                "/dev/stdin"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-1",
                        "position": -2
                    },
                    "id": "#hisat2_align.cwl/fastq1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-2",
                        "position": -1
                    },
                    "id": "#hisat2_align.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--rna-strandness RF",
                        "position": -6
                    },
                    "id": "#hisat2_align.cwl/firststrand"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--rg"
                        }
                    },
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#hisat2_align.cwl/read_group_fields"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--rg-id",
                        "position": -5
                    },
                    "id": "#hisat2_align.cwl/read_group_id"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".1.ht2",
                        ".2.ht2",
                        ".3.ht2",
                        ".4.ht2",
                        ".5.ht2",
                        ".6.ht2",
                        ".7.ht2",
                        ".8.ht2"
                    ],
                    "inputBinding": {
                        "prefix": "-x",
                        "position": -3
                    },
                    "id": "#hisat2_align.cwl/reference_index"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--rna-strandness FR",
                        "position": -6
                    },
                    "id": "#hisat2_align.cwl/secondstrand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#hisat2_align.cwl/aligned_bam"
                }
            ],
            "id": "#hisat2_align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Kallisto: Quant",
            "baseCommand": [
                "/usr/bin/kallisto"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 8
                }
            ],
            "arguments": [
                "quant",
                "-t",
                "$(runtime.cores)",
                "-b",
                "100",
                "--fusion",
                "-o",
                "kallisto"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#kallisto.cwl/fastqs"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--fr-stranded",
                        "position": 1
                    },
                    "id": "#kallisto.cwl/firststrand"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 2
                    },
                    "id": "#kallisto.cwl/kallisto_index"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--rf-stranded",
                        "position": 1
                    },
                    "id": "#kallisto.cwl/secondstrand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "kallisto/abundance.h5"
                    },
                    "id": "#kallisto.cwl/expression_transcript_h5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "kallisto/abundance.tsv"
                    },
                    "id": "#kallisto.cwl/expression_transcript_table"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "kallisto/fusion.txt"
                    },
                    "id": "#kallisto.cwl/fusion_evidence"
                }
            ],
            "id": "#kallisto.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sambamba: merge",
            "baseCommand": [
                "/usr/bin/sambamba_merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                }
            ],
            "arguments": [
                "$(runtime.cores)",
                "$(runtime.outdir)/merged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "merged.bam"
                    },
                    "id": "#merge.cwl/merged_bam"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "StringTie",
            "baseCommand": [
                "/usr/bin/stringtie"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "coresMin": 16
                }
            ],
            "arguments": [
                "-o",
                "$(runtime.outdir)/stringtie_transcripts.gtf",
                "-A",
                "$(runtime.outdir)/stringtie_gene_expression.tsv",
                "-n",
                "$(runtime.cores)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#stringtie.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--rf",
                        "position": 1
                    },
                    "id": "#stringtie.cwl/firststrand"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-G",
                        "position": 2
                    },
                    "id": "#stringtie.cwl/reference_annotation"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-l",
                        "position": 3
                    },
                    "id": "#stringtie.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--fr",
                        "position": 1
                    },
                    "id": "#stringtie.cwl/secondstrand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stringtie_gene_expression.tsv"
                    },
                    "id": "#stringtie.cwl/gene_expression_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stringtie_transcripts.gtf"
                    },
                    "id": "#stringtie.cwl/transcript_gtf"
                }
            ],
            "id": "#stringtie.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Kallisto: TranscriptToGene",
            "baseCommand": [
                "/usr/local/bin/Rscript"
            ],
            "arguments": [
                "/usr/src/transcript_to_gene.R"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000,
                    "coresMin": 1
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#transcript_to_gene.cwl/gene_transcript_lookup_table"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#transcript_to_gene.cwl/transcript_table_h5"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "gene_abundance.tsv"
                    },
                    "id": "#transcript_to_gene.cwl/gene_abundance"
                }
            ],
            "id": "#transcript_to_gene.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Trim FASTQ (flexbar)",
            "baseCommand": [
                "/opt/flexbar/flexbar"
            ],
            "arguments": [
                "--target",
                {
                    "valueFrom": "$(runtime.outdir)/trimmed_read"
                },
                "--threads",
                {
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 25000,
                    "coresMin": 4
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--adapter-min-overlap",
                        "position": 3
                    },
                    "id": "#trim_fastq.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--adapter-trim-end",
                        "position": 2
                    },
                    "id": "#trim_fastq.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--adapters",
                        "position": 1
                    },
                    "id": "#trim_fastq.cwl/adapters"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--max-uncalled",
                        "position": 5
                    },
                    "id": "#trim_fastq.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-read-length",
                        "position": 6
                    },
                    "id": "#trim_fastq.cwl/min_readlength"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads",
                        "position": 7
                    },
                    "id": "#trim_fastq.cwl/reads1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads2",
                        "position": 8
                    },
                    "id": "#trim_fastq.cwl/reads2"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "trimmed_read_*.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastqs"
                }
            ],
            "id": "#trim_fastq.cwl"
        },
        {
            "class": "Workflow",
            "label": "RNA-Seq alignment and transcript/gene abundance workflow",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/firststrand"
                },
                {
                    "type": "File",
                    "id": "#main/gene_transcript_lookup_table"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/instrument_data_bams"
                },
                {
                    "type": "File",
                    "id": "#main/kallisto_index"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#main/read_group_fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/read_group_id"
                },
                {
                    "type": "File",
                    "id": "#main/refFlat"
                },
                {
                    "type": "File",
                    "id": "#main/reference_annotation"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".1.ht2",
                        ".2.ht2",
                        ".3.ht2",
                        ".4.ht2",
                        ".5.ht2",
                        ".6.ht2",
                        ".7.ht2",
                        ".8.ht2"
                    ],
                    "id": "#main/reference_index"
                },
                {
                    "type": "File",
                    "id": "#main/ribosomal_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/secondstrand"
                },
                {
                    "type": "string",
                    "id": "#main/strand"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#main/trimming_adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#main/trimming_adapters"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_min_readlength"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/generate_qc_metrics/chart",
                    "id": "#main/chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/final_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kallisto/fusion_evidence",
                    "id": "#main/fusion_evidence"
                },
                {
                    "type": "File",
                    "outputSource": "#main/transcript_to_gene/gene_abundance",
                    "id": "#main/gene_abundance"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_qc_metrics/metrics",
                    "id": "#main/metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/stringtie/gene_expression_tsv",
                    "id": "#main/stringtie_gene_expression_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/stringtie/transcript_gtf",
                    "id": "#main/stringtie_transcript_gtf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kallisto/expression_transcript_h5",
                    "id": "#main/transcript_abundance_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kallisto/expression_transcript_table",
                    "id": "#main/transcript_abundance_tsv"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_trimmed_fastq_and_hisat_alignments.cwl",
                    "scatter": [
                        "#main/bam_to_trimmed_fastq_and_hisat_alignments/bam",
                        "#main/bam_to_trimmed_fastq_and_hisat_alignments/read_group_id",
                        "#main/bam_to_trimmed_fastq_and_hisat_alignments/read_group_fields"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/trimming_adapter_min_overlap",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/adapter_min_overlap"
                        },
                        {
                            "source": "#main/trimming_adapter_trim_end",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/adapter_trim_end"
                        },
                        {
                            "source": "#main/trimming_adapters",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/adapters"
                        },
                        {
                            "source": "#main/instrument_data_bams",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/bam"
                        },
                        {
                            "source": "#main/firststrand",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/firststrand"
                        },
                        {
                            "source": "#main/trimming_max_uncalled",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/max_uncalled"
                        },
                        {
                            "source": "#main/trimming_min_readlength",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/min_readlength"
                        },
                        {
                            "source": "#main/read_group_fields",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/read_group_fields"
                        },
                        {
                            "source": "#main/read_group_id",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/read_group_id"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/reference_index"
                        },
                        {
                            "source": "#main/secondstrand",
                            "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments/secondstrand"
                        }
                    ],
                    "out": [
                        "#main/bam_to_trimmed_fastq_and_hisat_alignments/fastqs",
                        "#main/bam_to_trimmed_fastq_and_hisat_alignments/aligned_bam"
                    ],
                    "id": "#main/bam_to_trimmed_fastq_and_hisat_alignments"
                },
                {
                    "run": "#generate_qc_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/index_bam/indexed_bam",
                            "id": "#main/generate_qc_metrics/bam"
                        },
                        {
                            "source": "#main/refFlat",
                            "id": "#main/generate_qc_metrics/refFlat"
                        },
                        {
                            "source": "#main/ribosomal_intervals",
                            "id": "#main/generate_qc_metrics/ribosomal_intervals"
                        },
                        {
                            "source": "#main/strand",
                            "id": "#main/generate_qc_metrics/strand"
                        }
                    ],
                    "out": [
                        "#main/generate_qc_metrics/metrics",
                        "#main/generate_qc_metrics/chart"
                    ],
                    "id": "#main/generate_qc_metrics"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#main/index_bam/indexed_bam"
                    ],
                    "id": "#main/index_bam"
                },
                {
                    "run": "#kallisto.cwl",
                    "in": [
                        {
                            "source": "#main/bam_to_trimmed_fastq_and_hisat_alignments/fastqs",
                            "valueFrom": "${\n  for(var i=0;i<self.length;i++){self[i] = self[i].reverse()}\n  return(self)\n }\n",
                            "id": "#main/kallisto/fastqs"
                        },
                        {
                            "source": "#main/firststrand",
                            "id": "#main/kallisto/firststrand"
                        },
                        {
                            "source": "#main/kallisto_index",
                            "id": "#main/kallisto/kallisto_index"
                        },
                        {
                            "source": "#main/secondstrand",
                            "id": "#main/kallisto/secondstrand"
                        }
                    ],
                    "out": [
                        "#main/kallisto/expression_transcript_table",
                        "#main/kallisto/expression_transcript_h5",
                        "#main/kallisto/fusion_evidence"
                    ],
                    "id": "#main/kallisto"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#main/bam_to_trimmed_fastq_and_hisat_alignments/aligned_bam",
                            "id": "#main/merge/bams"
                        }
                    ],
                    "out": [
                        "#main/merge/merged_bam"
                    ],
                    "id": "#main/merge"
                },
                {
                    "run": "#stringtie.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/stringtie/bam"
                        },
                        {
                            "source": "#main/firststrand",
                            "id": "#main/stringtie/firststrand"
                        },
                        {
                            "source": "#main/reference_annotation",
                            "id": "#main/stringtie/reference_annotation"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/stringtie/sample_name"
                        },
                        {
                            "source": "#main/secondstrand",
                            "id": "#main/stringtie/secondstrand"
                        }
                    ],
                    "out": [
                        "#main/stringtie/transcript_gtf",
                        "#main/stringtie/gene_expression_tsv"
                    ],
                    "id": "#main/stringtie"
                },
                {
                    "run": "#transcript_to_gene.cwl",
                    "in": [
                        {
                            "source": "#main/gene_transcript_lookup_table",
                            "id": "#main/transcript_to_gene/gene_transcript_lookup_table"
                        },
                        {
                            "source": "#main/kallisto/expression_transcript_h5",
                            "id": "#main/transcript_to_gene/transcript_table_h5"
                        }
                    ],
                    "out": [
                        "#main/transcript_to_gene/gene_abundance"
                    ],
                    "id": "#main/transcript_to_gene"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
